@@ -1,7 +1,7 @@
 package Module::DataPack;
 
-our $DATE = '2015-11-27'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2016-02-09'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -91,6 +91,16 @@ _
         },
 
     },
+    examples => [
+        {
+            summary => 'Datapack two modules',
+            src => 'datapack-modules Text::Table::Tiny Try::Tiny',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+
+    ],
 };
 sub datapack_modules {
     my %args = @_;
@@ -254,15 +264,7 @@ Module::DataPack - Like Module::FatPack, but uses datapacking instead of fatpack
 
 =head1 VERSION
 
-This document describes version 0.16 of Module::DataPack (from Perl distribution Module-DataPack), released on 2015-11-27.
-
-=head1 SEE ALSO
-
-L<App::FatPack>, L<App::depak>
-
-L<Data::Section::Seekable>, the format used for the data section
-
-L<datapack-modules>, CLI for C<datapack_modules>.
+This document describes version 0.17 of Module::DataPack (from Perl distribution Module-DataPack), released on 2016-02-09.
 
 =head1 FUNCTIONS
 
@@ -370,13 +372,24 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Module::FatPack> for a similar module which uses fatpacking technique instead
+of datapacking.
+
+L<App::depak> for more options e.g. use various tracing methods, etc.
+
+L<Data::Section::Seekable>, the format used for the data section
+
+L<datapack-modules>, CLI for C<datapack_modules>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
